coniql
======

|code_ci| |docs_ci| |coverage| |pypi_version| |license|

Control system interface in GraphQL with plugins for EPICS Channel Access and PV Access.
Supports a web interface to get, put and monitor the value of PVs.


.. |code_ci| image:: https://github.com/DiamondLightSource/coniql/actions/workflows/code.yml/badge.svg?branch=main
    :target: https://github.com/DiamondLightSource/coniql/actions/workflows/code.yml
    :alt: Code CI

.. |docs_ci| image:: https://github.com/DiamondLightSource/coniql/actions/workflows/docs.yml/badge.svg?branch=main
    :target: https://github.com/DiamondLightSource/coniql/actions/workflows/docs.yml
    :alt: Docs CI

.. |coverage| image:: https://codecov.io/gh/DiamondLightSource/coniql/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/DiamondLightSource/coniql
    :alt: Test Coverage

.. |pypi_version| image:: https://img.shields.io/pypi/v/coniql.svg
    :target: https://pypi.org/project/coniql

.. |license| image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
    :target: https://opensource.org/licenses/Apache-2.0
    :alt: Apache License

..
    Anything below this line is used when viewing README.rst and will be replaced
    when included in index.rst

See https://DiamondLightSource.github.io/coniql for more detailed documentation.
